#' @name Atmosfera
#' @title Temperatura e Umidade do Ar na Cidade de São Paulo
#' @description Dados atmosféricos sobre temperatura
#'     (\code{Temperatura}) e umidade relativa do ar (\code{Umidade}),
#'     mensuradas ao meio-dia, na cidade de São Paulo. Observações
#'     diárias referentes a 1º de Janeiro a 31 de Dezembro de 1997.
#' @format Uma série temporal bivariada (classe \code{mts}), com 365
#'     observações diárias de 1º de Janeiro a 31 de Dezembro de 1997,
#'     das seguintes medidas:
#'
#' \describe{
#'
#' \item{\code{Temperatura}}{Temperaturas, mensuradas ao meio-dia em
#'     [VER UNIDADE DE MEDIDA].}
#'
#' \item{\code{Umidade}}{Umidades relativa do ar, mensuradas ao meio-dia
#'     em [VER UNIDADE DE MEDIDA].}
#'
#' }
#' @seealso \code{\link{Poluentes}}.
#' @keywords TS MTS
#' @source Morettin, P. A., Toloi, C. M. C. (2006). Análise de Séries
#'     Temporais (2nd ed.). São Paulo, SP: Editora Egard Blucher. (Série
#'     A7 - Atmosfera, mencionada em diversas páginas)
#' @examples
#'
#' data(Atmosfera)
#' str(Atmosfera)
#' Atmosfera
#'
#' # Estatísticas resumo das séries
#' apply(Atmosfera, 2, summary)
#'
#' # Visualização da série
#' library(lattice)
#' xyplot(Atmosfera, type = c("o", "g"), pch = 19, col = "turquoise")
#'
#' # Mesclando com as séries dos agentes poluentes no mesmo período
#' # help(Poluentes)
#' series <- ts.union(Atmosfera, Poluentes)
#' xyplot(series, type = c("o", "g"), pch = 20, col = "black")
#'
NULL
