#' @name Energia
#' @title Consumo de Energia Elétrica no Espírito Santo
#' @description Dados sobre o consumo de energia elétrica no estado do
#'     Espírito Santo. A série é referente a valores mensais de consumo
#'     no período de Janeiro de 1968 a Setembro de 1979.
#'
#' @format Uma série temporal (classe \code{ts}), com 141 observações
#'     mensais de Janeiro de 1968 a Setembro de 1979.
#' @keywords TS
#' @source Morettin, P. A., Toloi, C. M. C. (2006). Análise de Séries
#'     Temporais (2nd ed.). São Paulo, SP: Editora Egard
#'     Blucher. (Série A5 - Energia, mencionada em diversas
#'     páginas)
#' @examples
#'
#' data(Energia)
#' str(Energia)
#' Energia
#'
#' # Médias anuais
#' aggregate(Energia, FUN = mean)
#'
#' # Médias mensais
#' tapply(Energia, cycle(Energia), mean)
#'
#' # Visualização da série
#' library(lattice)
#' xyplot(Energia, type = c("o", "g"), pch = 19, col = "lightblue")
#'
#' # Gráfico da decomposição sazonal
#' library(latticeExtra)
#' xyplot(stl(Energia, s.window = 12), col = "yellowgreen")
#'
NULL
