#' @name Globo
#' @title Ações da Globo Cabo
#' @description Dados sobre os preços diários das ações da Globo Cabo de
#'     06 de Novembro de 1996 a 27 de Dezembro de 2000. Os dados foram
#'     registrados apenas nos dias utéis dentre o período indicado.
#' @format Uma série temporal irregularmente espaçada (classe
#'     \code{\link[zoo]{zoo}}), com 1037 observações dos dias utéis de
#'     06 de Novembro de 1996 a 27 de Dezembro de 2000.
#' @seealso \code{\link{Banespa}}, \code{\link{Cemig}}, \code{\link{IBV}},
#'     \code{\link{Petro}} e \code{\link{TAM}}.
#' @keywords TS TSI
#' @source Morettin, P. A., Toloi, C. M. C. (2006). Análise de Séries
#'     Temporais (2nd ed.). São Paulo, SP: Editora Egard Blucher. (Série
#'     A9 - Mercado Financeiro, mencionada em diversas páginas)
#' @examples
#'
#' data(Globo)
#'
#' library(zoo)
#' str(Globo)
#' Globo
#'
#' # Médias anuais e mensais
#' aggregate(Globo, by = format(time(Globo), "%Y"), FUN = mean)
#' aggregate(Globo, by = format(time(Globo), "%B"), FUN = mean)
#'
#' # Visualização da série
#' library(lattice)
#' xyplot(Globo, type = c("o", "g"), pch = 19, col = "violet")
#'
#' # Visualizando os dados diários sobre o mercado financeiro presentes
#' # em MORETTIN (2006)
#' # sapply(c("Banespa", "Cemig", "IBV", "Petro", "TAM"), help)
#' series <- merge(Globo, Banespa, Cemig, IBV, Petro, TAM)
#' xyplot(series, grid = TRUE, col = "black")
#'
NULL
