#' @name IBV
#' @title Índice da Bolsa de Valores de São Paulo
#' @description Dados sobre o índice da bolsa de valores (IBV) de São
#'     Paulo. Os dados são referentes a observações diárias, apenas dias
#'     utéis, no período de 03 de Janeiro de 1995 até 27 de Dezembro de
#'     2000.
#' @format Uma série temporal irregularmente espaçada (classe
#'     \code{\link[zoo]{zoo}}), com 1498 observações diárias, de 3 de
#'     janeiro de 1995 a 27 de dezembro de 2000.
#' @seealso \code{\link{Banespa}}, \code{\link{Cemig}},
#'     \code{\link{Globo}}, \code{\link{Petro}} e \code{\link{TAM}}.
#' @keywords TS TSI
#' @source Morettin, P. A., Toloi, C. M. C. (2006). Análise de Séries
#'     Temporais (2nd ed.). São Paulo, SP: Editora Egard Blucher. (Série
#'     A9 - Mercado Financeiro, mencionada em diversas páginas)
#' @examples
#'
#' data(IBV)
#'
#' library(zoo)
#' str(IBV)
#' IBV
#'
#' # Médias anuais
#' aggregate(IBV, by = format(time(IBV), "%Y"), FUN = mean)
#' aggregate(IBV, by = format(time(IBV), "%B"), FUN = mean)
#'
#' # Visualização da série
#' library(lattice)
#' xyplot(IBV, type = c("o", "g"), pch = 19, col = "salmon")
#'
#' # Visualizando os dados diários sobre o mercado financeiro presentes
#' # em MORETTIN (2006)
#' # sapply(c("Banespa", "Cemig", "Globo", "Petro", "TAM"), help)
#' series <- merge(IBV, Banespa, Cemig, Globo, Petro, TAM)
#' xyplot(series, grid = TRUE, col = "black")
#'
NULL
