#' @name IPI
#' @title Imposto Sobre Produtos Industrializados do Brasil
#' @description Dados de imposto sobre produtos industrializados (IPI),
#'     de produtos alimentares do Brasil. As observações são mensais e
#'     referentes ao período de Janeiro de 1985 a Julho de 2000.
#' @format Uma série temporal (classe \code{ts}), com 187 observações
#'     mensais de Janeiro de 1985 a Julho de 2000.
#' @keywords TS
#' @source Morettin, P. A., Toloi, C. M. C. (2006). Análise de Séries
#'     Temporais (2nd ed.). São Paulo, SP: Editora Egard Blucher. (Série
#'     A8 - Índices, mencionada em diversas páginas)
#' @examples
#'
#' data(IPI)
#' str(IPI)
#' IPI
#'
#' # Médias anuais
#' aggregate(IPI, FUN = mean)
#'
#' # Médias mensais
#' tapply(IPI, cycle(IPI), mean)
#'
#' # Visualização da série
#' library(lattice)
#' xyplot(IPI, type = c("o", "g"), pch = 19, col = "sienna")
#'
#' # Gráfico da decomposição sazonal
#' library(latticeExtra)
#' xyplot(stl(IPI, s.window = 12), col = "navyblue")
#'
NULL
