#' @name PFI
#' @title Produção Física Industrial do Brasil
#' @description Dados sobre a produção física industrial (PFI), da
#'     indústria geral, do Brasil. As observações são mensais e
#'     referentes ao período de Janeiro de 1991 a Julho de 2000.
#' @format Uma série temporal (classe \code{ts}), com 115 observações
#'     mensais de Janeiro de 1991 a Julho de 2000.
#' @keywords TS
#' @source Morettin, P. A., Toloi, C. M. C. (2006). Análise de Séries
#'     Temporais (2nd ed.). São Paulo, SP: Editora Egard Blucher. (Série
#'     A8 - Índices, mencionada em diversas páginas)
#' @examples
#'
#' data(PFI)
#' str(PFI)
#' PFI
#'
#' # Médias anuais
#' aggregate(PFI, FUN = mean)
#'
#' # Médias mensais
#' tapply(PFI, cycle(PFI), mean)
#'
#' # Visualização da série
#' library(lattice)
#' xyplot(PFI, type = c("o", "g"), pch = 19, col = "sienna")
#'
#' # Gráfico da decomposição sazonal
#' library(latticeExtra)
#' xyplot(stl(PFI, s.window = 12), col = "navyblue")
#'
NULL
