#' @name Petro
#' @title Ações Preferenciais da Petrobras
#' @description Dados sobre os valores diários das ações preferenciais
#'     da Petrobras - Petrobras PN. Os dados são referentes ao período
#'     do dia 03 de Janeiro de 1995 até 27 de Dezembro de 2000,
#'     contabilizados somente nos dias utéis.
#' @format Uma série temporal irregularmente espaçada (classe
#'     \code{\link[zoo]{zoo}}), com 1498 observações dos dias utéis de
#'     03 de janeiro de 1995 a 27 de dezembro de 2000.
#' @seealso \code{\link{Banespa}}, \code{\link{Cemig}},
#'     \code{\link{Globo}}, \code{\link{IBV}} e \code{\link{TAM}}.
#' @keywords TS TSI
#' @source Morettin, P. A., Toloi, C. M. C. (2006). Análise de Séries
#'     Temporais (2nd ed.). São Paulo, SP: Editora Egard Blucher. (Série
#'     A9 - Mercado Financeiro, mencionada em diversas páginas)
#' @examples
#'
#' data(Petro)
#'
#' library(zoo)
#' str(Petro)
#' Petro
#'
#' # Médias anuais e mensais
#' aggregate(Petro, by = format(time(Petro), "%Y"), FUN = mean)
#' aggregate(Petro, by = format(time(Petro), "%B"), FUN = mean)
#'
#' # Visualização da série
#' library(lattice)
#' xyplot(Petro, type = c("o", "g"), pch = 19, col = "violetred3")
#'
#' # Visualizando os dados diários sobre o mercado financeiro presentes
#' # em MORETTIN (2006)
#' # sapply(c("Banespa", "Cemig", "Globo", "IBV", "TAM"), help)
#' series <- merge(Petro, Banespa, Cemig, Globo, IBV, TAM)
#' xyplot(series, grid = TRUE, col = "black")
#'
NULL
